'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = _interopDefault(require('prop-types'));

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".styles_minimapWindow__2BGG2 {\n  width: 114px;\n  height: 300px;\n  position: fixed;\n  top: 0;\n  right: 0;\n  overflow: scroll;\n  overflow: hidden;\n}\n\n.styles_minimapWindow__preview__3XdwA {\n  width: 100vw;\n  position: absolute;\n  left: 0;\n  top: 0;\n  z-index: 999;\n  transform-origin: left top;\n}\n";
var styles = { "minimapWindow": "styles_minimapWindow__2BGG2", "minimapWindow__preview": "styles_minimapWindow__preview__3XdwA" };
styleInject(css);

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var Minimap = function (_Component) {
  inherits(Minimap, _Component);

  function Minimap(props) {
    classCallCheck(this, Minimap);

    var _this = possibleConstructorReturn(this, (Minimap.__proto__ || Object.getPrototypeOf(Minimap)).call(this, props));

    _this.updateWidth = function () {
      _this.setState(function () {
        return {
          windowWidth: document.documentElement.clientWidth
        };
      });
    };

    _this.updateScrollPercent = function () {
      var winScroll = document.body.scrollTop || document.documentElement.scrollTop;

      var height = document.documentElement.scrollHeight - document.documentElement.clientHeight;

      var scrolled = winScroll / height;
      _this.scrollToPercent();
      _this.setState(function () {
        return {
          scrollPercent: scrolled
        };
      });
    };

    _this.scrollToPercent = function () {
      var scrollPercent = _this.state.scrollPercent;

      var minimap = _this.refMinimap.current;

      var minimapHeight = minimap.clientHeight;
      var scrollHeight = minimap.scrollHeight;

      var height = scrollHeight - minimapHeight;

      minimap.scrollTo(0, height * scrollPercent);
    };

    _this.computePreviewStyle = function () {
      var windowWidth = _this.state.windowWidth;
      var width = _this.props.width;

      var scale = width / windowWidth;
      return { transform: 'scale(' + (scale || 1) + ')' };
    };

    _this.computeMinimapStyle = function () {
      var _this$props = _this.props,
          width = _this$props.width,
          height = _this$props.height;

      return { width: width, height: height };
    };

    _this.refMinimap = React__default.createRef();
    _this.state = {
      scrollPercent: 0,
      windowScroll: 0,
      windowWidth: document.documentElement.clientWidth
    };
    return _this;
  }

  createClass(Minimap, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      window.addEventListener('scroll', this.updateScrollPercent);
      window.addEventListener('resize', this.updateWidth);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('scroll', this.updateScrollPercent);
      window.removeEventListener('resize', this.updateWidth);
    }
  }, {
    key: 'render',
    value: function render() {
      var of = this.props.of;

      var previewStyle = this.computePreviewStyle();
      var minimapStyle = this.computeMinimapStyle();

      return React__default.createElement(
        'div',
        {
          className: styles.minimapWindow,
          style: minimapStyle,
          ref: this.refMinimap
        },
        React__default.createElement(
          'div',
          { className: styles.minimapWindow__preview, style: previewStyle },
          of
        )
      );
    }
  }]);
  return Minimap;
}(React.Component);

Minimap.propTypes = {
  of: PropTypes.node.isRequired,
  width: PropTypes.number,
  height: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
};

Minimap.defaultProps = {
  width: 114,
  height: 300
};

module.exports = Minimap;
//# sourceMappingURL=index.js.map
